@@ -137,6 +137,7 @@ typedef struct _TotemEmbedded {
 	GtkWidget * fs_window;
 
 	/* Error */
+	GError *error;
 
 	guint type : 3; /* TotemPluginType */
 
@@ -172,6 +173,7 @@ static void totem_embedded_init (TotemEmbedded *emb) { }
 static gboolean totem_embedded_do_command (TotemEmbedded *emb, const char *command, GError **err);
 static gboolean totem_embedded_push_parser (gpointer data);
 static gboolean totem_embedded_play (TotemEmbedded *embedded, GError **error);
+static void totem_embedded_set_logo_by_name (TotemEmbedded *embedded, const char *name);
 
 static void totem_embedded_clear_playlist (TotemEmbedded *embedded);
 
@@ -287,13 +289,25 @@ totem_embedded_save_volume (TotemEmbedded *emb, double volume)
 
 static void
 totem_embedded_set_error (TotemEmbedded *emb,
-			  char *primary,
+			  int code,
 			  char *secondary)
 {
-	/* FIXME */
-	g_message ("totem_embedded_set_error: '%s', '%s'", primary, secondary);
+	emb->error = g_error_new (TOTEM_EMBEDDED_ERROR_QUARK,
+				  code,
+				  secondary);
+	g_message ("totem_embedded_set_error: '%s'", secondary);
 }
 
+static gboolean
+totem_embedded_set_error_logo (TotemEmbedded *embedded,
+			       GError *error)
+{
+	g_message ("totem_embedded_set_error_logo called by browser plugin");
+	totem_embedded_set_logo_by_name (embedded, "image-missing");
+	return TRUE;
+}
+
+
 static void
 totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 {
@@ -388,7 +402,7 @@ totem_embedded_set_logo_by_name (TotemEmbedded *embedded,
 
 	totem_embedded_set_state (embedded, TOTEM_STATE_STOPPED);
 
-	if (embedded->audioonly != FALSE)
+	if (embedded->audioonly != FALSE || embedded->hidden != FALSE)
 		return;
 
 	theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (embedded->window));
@@ -454,23 +468,19 @@ totem_embedded_open_internal (TotemEmbedded *emb,
 	if (retval == FALSE)
 	{
 		GError *errint;
-		char *primary;
 
 		/* FIXME we haven't even started sending yet! */
 		//g_signal_emit (emb, signals[STOP_STREAM], 0);
 
 		totem_embedded_set_state (emb, TOTEM_STATE_STOPPED);
-		totem_embedded_set_logo_by_name (emb, "image-missing");
+		totem_embedded_set_error_logo (emb, NULL);
 
 		errint = g_error_new (TOTEM_EMBEDDED_ERROR_QUARK,
 				      TOTEM_EMBEDDED_OPEN_FAILED,
 				      _("Totem could not play '%s'"),
 				     emb->current_uri);
 
-		//FIXME disp = gnome_vfs_unescape_string_for_display (totem->mrl); ?
-		primary = g_strdup_printf(_("Totem could not play '%s'"), emb->current_uri);
-		totem_embedded_set_error (emb, primary, err->message);;
-		g_free (primary);
+		totem_embedded_set_error (emb, err->code, err->message);;
 
 		g_propagate_error (error, err);
 
@@ -498,7 +508,12 @@ totem_embedded_play (TotemEmbedded *emb,
 {
 	GError *err = NULL;
 
-	g_return_val_if_fail (emb->current_uri != NULL, FALSE);
+	if (emb->current_uri == NULL) {
+		totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), FALSE);
+		g_signal_emit (emb, signals[BUTTON_PRESS], 0,
+			       gtk_get_current_event_time (), 0);
+		return TRUE;
+	}
 
 	totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), FALSE);
 
@@ -584,15 +599,6 @@ totem_embedded_set_href (TotemEmbedded *embedded,
 	return TRUE;
 }
 
-static gboolean
-totem_embedded_set_error_logo (TotemEmbedded *embedded,
-			       GError *error)
-{
-	g_message ("totem_embedded_set_error_logo called by browser plugin");
-	totem_embedded_set_logo_by_name (embedded, "image-missing");
-	return TRUE;
-}
-
 static gboolean
 totem_embedded_set_volume (TotemEmbedded *embedded,
 			   gdouble volume,
@@ -1452,7 +1458,11 @@ on_video_button_press_event (BaconVideoWidget *bvw,
 	menu = GTK_MENU (gtk_builder_get_object (emb->menuxml, "menu"));
 
 	if (event->type == GDK_BUTTON_PRESS && event->button == 1 && state == 0 && emb->state == TOTEM_STATE_STOPPED) {
-		if (!GTK_WIDGET_VISIBLE (menu)) {
+		if (emb->error != NULL) {
+			totem_interface_error (_("An error occurred"), emb->error->message, (GtkWindow *) (emb->window));
+			g_error_free (emb->error);
+			emb->error = NULL;
+		} else if (!GTK_WIDGET_VISIBLE (menu)) {
 			g_message ("emitting signal");
 			g_signal_emit (emb, signals[BUTTON_PRESS], 0,
 				       event->time,
@@ -1561,7 +1571,8 @@ on_error_event (BaconVideoWidget *bvw,
 		exit (1);
 	}
 
-	totem_embedded_set_error (emb, _("An error occurred"), message);
+	totem_embedded_set_error (emb, BVW_ERROR_GENERIC, message);
+	totem_embedded_set_error_logo (emb, NULL);
 }
 
 static void
@@ -2140,9 +2151,9 @@ totem_embedded_push_parser (gpointer data)
 	/* Check if we have anything in the playlist now */
 	if (emb->playlist == NULL && res != TOTEM_PL_PARSER_RESULT_SUCCESS) {
 		g_message ("Couldn't parse playlist '%s'", emb->current_uri);
-		totem_embedded_set_error (emb, _("No playlist or playlist empty") /* FIXME */,
-					  NULL);
-		totem_embedded_set_logo_by_name (emb, "image-missing");
+		totem_embedded_set_error (emb, BVW_ERROR_EMPTY_FILE,
+					  _("No playlist or playlist empty"));
+		totem_embedded_set_error_logo (emb, NULL);
 		return FALSE;
 	} else if (emb->playlist == NULL) {
 		g_message ("Playlist empty");
