@@ -19,7 +19,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: totemNarrowSpacePlugin.cpp 4845 2007-11-01 16:05:27Z hadess $
+ * $Id: totemNarrowSpacePlugin.cpp 5065 2008-02-04 14:32:50Z hadess $
  */
 
 #include <mozilla-config.h>
@@ -88,6 +88,12 @@ totemScriptablePlugin::PluginDescription ()
   return (char*) kPluginDescription;
 }
 
+/* static */ char *
+totemScriptablePlugin::PluginLongDescription ()
+{
+  return (char*) totem_plugin_get_long_description();
+}
+
 /* static */ void
 totemScriptablePlugin::PluginMimeTypes (const totemPluginMimeEntry **_entries,
 					PRUint32 *_count)
