@@ -56,10 +56,8 @@
 #include <nsIDOMElement.h>
 #include <nsIDOM3Node.h>
 #include <nsIIOService.h>
-#include <nsIURI.h>
 #include <nsITimer.h>
 #include <nsIComponentManager.h>
-#include <nsIServiceManager.h>
 #include <nsIProtocolHandler.h>
 #include <nsIExternalProtocolHandler.h>
 
@@ -1117,9 +1115,9 @@ totemPlugin::ParseBoolean (const char *key,
 {
 	if (value == NULL || strcmp (value, "") == 0)
 		return default_val;
-	if (g_ascii_strcasecmp (value, "false") == 0)
+	if (g_ascii_strcasecmp (value, "false") == 0 || g_ascii_strcasecmp (value, "no") == 0)
 		return PR_FALSE;
-	if (g_ascii_strcasecmp (value, "true") == 0)
+	if (g_ascii_strcasecmp (value, "true") == 0 || g_ascii_strcasecmp (value, "yes") == 0)
 		return PR_TRUE;
 
         char *endptr = NULL;
@@ -1728,10 +1726,13 @@ totemPlugin::Init (NPMIMEType mimetype,
 	mHidden = g_hash_table_lookup (args, "hidden") != NULL &&
 		  GetBooleanValue (args, "hidden", PR_TRUE);
 
-	/* Most for RealAudio streams, but also used as a replacement for
-	 * HIDDEN=TRUE attribute.
+	/* Used as a replacement for HIDDEN=TRUE attribute.
+	 * See http://mxr.mozilla.org/mozilla/source/modules/plugin/base/src/ns4xPluginInstance.cpp#1135
+	 * We don't use:
+	 * width <= 0 || height <= 0
+	 * as -1 is our value for unset/unknown sizes
 	 */
-	if (width == 0 && height == 0)
+	if (width == 0 || height == 0)
 		mHidden = PR_TRUE;
 
 	/* Whether to automatically stream and play the content */
@@ -1790,12 +1791,26 @@ totemPlugin::Init (NPMIMEType mimetype,
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
 
 /* FIXME */
+#ifdef TOTEM_MULLY_PLUGIN
+	value = (const char *) g_hash_table_lookup (args, "video");
+	if (value) {
+		SetSrc (nsDependentCString (value));
+	}
+#endif /* TOTEM_MULLY_PLUGIN */
+
+#ifdef TOTEM_CONE_PLUGIN
+	value = (const char *) g_hash_table_lookup (args, "target");
+	if (value) {
+		SetSrc (nsDependentCString (value));
+	}
+#endif /* TOTEM_CONE_PLUGIN */
+
 #if 0 //def TOTEM_MULLY_PLUGIN
 	/* Click to play behaviour of the DivX plugin */
 	char *previewimage = (const char *) g_hash_table_lookup (args, "previewimage");
 	if (value != NULL)
 		mHref = g_strdup (mSrc);
-#endif /* TOTEM_NARROWSPACE_PLUGIN */
+#endif /* TOTEM_MULLY_PLUGIN */
 
 	/* If we're set to start automatically, we'll use the src stream */
 	if (mRequestURI &&
@@ -2140,6 +2155,8 @@ totemPlugin::Write (NPStream *stream,
 						    G_TYPE_INVALID);
 
 			return len;
+		} else {
+			D ("Is not playlist: totem_pl_parser_can_parse_from_data failed (len %d)", len);
 		}
 	}
 
