@@ -28,7 +28,6 @@
 #ifndef __TOTEM_PRIVATE_H__
 #define __TOTEM_PRIVATE_H__
 
-#include <glade/glade.h>
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -36,15 +35,17 @@
 #include "totem-playlist.h"
 #include "bacon-message-connection.h"
 #include "bacon-video-widget.h"
+#include "totem-open-location.h"
+#include "totem-fullscreen.h"
 
 #define totem_signal_block_by_data(obj, data) (g_signal_handlers_block_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
 #define totem_signal_unblock_by_data(obj, data) (g_signal_handlers_unblock_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
 
-#define totem_set_sensitivity(xml, name, state)		\
-	{							\
-		GtkWidget *widget;				\
-		widget = glade_xml_get_widget (xml, name);	\
-		gtk_widget_set_sensitive (widget, state);	\
+#define totem_set_sensitivity(xml, name, state)					\
+	{									\
+		GtkWidget *widget;						\
+		widget = GTK_WIDGET (gtk_builder_get_object (xml, name));	\
+		gtk_widget_set_sensitive (widget, state);			\
 	}
 #define totem_main_set_sensitivity(name, state) totem_set_sensitivity (totem->xml, name, state)
 
@@ -56,6 +57,7 @@
 	}
 
 typedef enum {
+	TOTEM_CONTROLS_UNDEFINED,
 	TOTEM_CONTROLS_VISIBLE,
 	TOTEM_CONTROLS_HIDDEN,
 	TOTEM_CONTROLS_FULLSCREEN
@@ -71,7 +73,7 @@ struct TotemObject {
 	GObject parent;
 
 	/* Control window */
-	GladeXML *xml;
+	GtkBuilder *xml;
 	GtkWidget *win;
 	BaconVideoWidget *bvw;
 	GtkWidget *prefs;
@@ -112,10 +114,6 @@ struct TotemObject {
 
 	/* Volume */
 	GtkWidget *volume;
-	gboolean vol_lock;
-	gboolean vol_fs_lock;
-	gfloat prev_volume;
-	int volume_first_time;
 	gboolean volume_sensitive;
 
 	/* Subtitles/Languages menus */
@@ -123,25 +121,14 @@ struct TotemObject {
 	GtkWidget *languages;
 	GList *subtitles_list;
 	GList *language_list;
+	gboolean autoload_subs;
 
-	/* exit fullscreen Popup */
-	GtkWidget *exit_popup;
+	/* Fullscreen */
+	TotemFullscreen *fs;
 
 	/* controls management */
 	ControlsVisibility controls_visibility;
 
-	/* control fullscreen Popup */
-	GtkWidget *control_popup;
-	GtkWidget *fs_seek;
-	GtkAdjustment *fs_seekadj;
-	GtkWidget *fs_volume;
-	GtkAdjustment *fs_voladj;
-	GtkWidget *tcw_time_label;
-
-	guint popup_timeout;
-	gboolean popup_in_progress;
-	GdkRectangle fullscreen_rect;
-
 	/* Stream info */
 	gint64 stream_length;
 
@@ -170,7 +157,7 @@ struct TotemObject {
 	GConfClient *gc;
 	BaconMessageConnection *conn;
 	TotemStates state;
-	gboolean cursor_shown;
+	TotemOpenLocation *open_location;
 };
 
 GtkWidget *totem_volume_create (void);
@@ -178,8 +165,8 @@ GtkWidget *totem_volume_create (void);
 #define SEEK_FORWARD_OFFSET 60
 #define SEEK_BACKWARD_OFFSET -15
 
-#define VOLUME_DOWN_OFFSET -8
-#define VOLUME_UP_OFFSET 8
+#define VOLUME_DOWN_OFFSET (-0.08)
+#define VOLUME_UP_OFFSET (0.08)
 
 #define ZOOM_IN_OFFSET 1
 #define ZOOM_OUT_OFFSET -1
