@@ -192,12 +192,23 @@ totem_action_save_state (Totem *totem, const char *page_id)
 	g_free (contents);
 }
 
+static void
+totem_action_wait_force_exit (gpointer user_data)
+{
+	g_usleep (10 * G_USEC_PER_SEC);
+	exit (1);
+}
+
 void
 totem_action_exit (Totem *totem)
 {
 	GdkDisplay *display = NULL;
 	char *page_id;
 
+	/* Exit forcefully if we can't do the shutdown in 10 seconds */
+	g_thread_create ((GThreadFunc) totem_action_wait_force_exit,
+			 NULL, FALSE, NULL);
+
 	if (gtk_main_level () > 0)
 		gtk_main_quit ();
 
@@ -470,15 +481,40 @@ totem_action_load_media (Totem *totem, TotemDiscMediaType type, const char *devi
 	char **mrls;
 	char *msg;
 	gboolean retval;
+	BaconVideoWidgetCanPlayStatus status;
 
-	if (bacon_video_widget_can_play (totem->bvw, type) == FALSE) {
-		if (type == MEDIA_TYPE_DVD || type == MEDIA_TYPE_VCD)
-			msg = g_strdup_printf(_("Totem cannot play this type of media (%s) because it does not have the appropriate plugins to be able to read from the disc."), _(totem_cd_get_human_readable_name (type)));
-		else
-			msg = g_strdup_printf (_("Totem cannot play this type of media (%s) because you do not have the appropriate plugins to handle it."), _(totem_cd_get_human_readable_name (type)));
-		totem_interface_error_with_link (msg, _("Please install the necessary plugins and restart Totem to be able to play this media."),
-				"http://www.gnome.org/projects/totem/#codecs", _("More information about media plugins"),
-				GTK_WINDOW (totem->win), totem);
+	status = bacon_video_widget_can_play (totem->bvw, type);
+
+	if (status != BVW_CAN_PLAY_SUCCESS) {
+		const char *link, *link_text, *secondary;
+
+		switch (status) {
+		case BVW_CAN_PLAY_MISSING_CHANNELS:
+			g_assert (type == MEDIA_TYPE_DVB);
+			link = "http://www.gnome.org/projects/totem/#dvb";
+			link_text = _("More information about watching TV");
+			msg = g_strdup (_("Totem is missing a channels listing to be able to tune the receiver."));
+			secondary = _("Please follow the instructions provided in the link to create a channels listing.");
+			break;
+		case BVW_CAN_PLAY_MISSING_PLUGINS:
+			link = "http://www.gnome.org/projects/totem/#codecs";
+			link_text = _("More information about media plugins");
+			secondary = _("Please install the necessary plugins and restart Totem to be able to play this media.");
+			if (type == MEDIA_TYPE_DVD || type == MEDIA_TYPE_VCD)
+				msg = g_strdup_printf (_("Totem cannot play this type of media (%s) because it does not have the appropriate plugins to be able to read from the disc."), _(totem_cd_get_human_readable_name (type)));
+			else
+				msg = g_strdup_printf (_("Totem cannot play this type of media (%s) because you do not have the appropriate plugins to handle it."), _(totem_cd_get_human_readable_name (type)));
+			break;
+		case BVW_CAN_PLAY_UNSUPPORTED:
+			msg = g_strdup_printf(_("Totem cannot play this type of media (%s) because it is not supported."), _(totem_cd_get_human_readable_name (type)));
+			totem_action_error (msg, _("Please insert another disc to play back."), totem);
+			g_free (msg);
+			return FALSE;
+		default:
+			g_assert_not_reached ();
+		}
+
+		totem_interface_error_with_link (msg, secondary, link, link_text, GTK_WINDOW (totem->win), totem);
 		g_free (msg);
 		return FALSE;
 	}
@@ -526,14 +562,7 @@ totem_action_load_media_device (Totem *totem, const char *device)
 			break;
 		case MEDIA_TYPE_DVD:
 		case MEDIA_TYPE_VCD:
-			{
-				const char *filenames[2];
-
-				filenames[0] = url;
-				filenames[1] = NULL;
-
-				retval = totem_action_open_files (totem, (char **) filenames);
-			}
+			retval = totem_action_load_media (totem, type, device_path);
 			break;
 		case MEDIA_TYPE_CDDA:
 			totem_action_error (_("Totem does not support playback of Audio CDs"),
@@ -1170,14 +1199,14 @@ totem_action_volume_relative (Totem *totem, double off_pct)
 
 void
 totem_action_toggle_aspect_ratio (Totem *totem)
-{		
+{
 	GtkAction *action;
 	int tmp;
 
 	tmp = totem_action_get_aspect_ratio (totem);
 	tmp++;
-	if (tmp > 4)
-		tmp = 0;
+	if (tmp > BVW_RATIO_DVB)
+		tmp = BVW_RATIO_AUTO;
 
 	action = gtk_action_group_get_action (totem->main_action_group, "aspect-ratio-auto");
 	gtk_radio_action_set_current_value (GTK_RADIO_ACTION (action), tmp);
@@ -2025,6 +2054,9 @@ totem_action_remote (Totem *totem, TotemRemoteCommand cmd, const char *url)
 	case TOTEM_REMOTE_COMMAND_MUTE:
 		totem_action_volume_relative (totem, -1.0);
 		break;
+	case TOTEM_REMOTE_COMMAND_TOGGLE_ASPECT:
+		totem_action_toggle_aspect_ratio (totem);
+		break;
 	default:
 		handled = FALSE;
 		break;
@@ -2528,7 +2560,8 @@ totem_action_handle_scroll (Totem *totem, GdkScrollDirection direction)
 {
 	gboolean retval = TRUE;
 
-	totem_fullscreen_motion_notify (NULL, NULL, totem->fs);
+	if (totem_fullscreen_is_fullscreen (totem->fs) != FALSE)
+		totem_fullscreen_motion_notify (NULL, NULL, totem->fs);
 
 	switch (direction) {
 	case GDK_SCROLL_UP:
